#include <gtk/gtk.h>
#include "obj_elem.h"
#include "hid.h"
#include "glue.h"

void ghid_pinout_window_show(pcb_gtk_common_t *com, pcb_subc_t *subc);

